@@ -104,14 +104,14 @@ typedef struct
   GClosure *closure;
   /* have gotten a notification from gtk */
   gboolean needs_gconf_sync;
-  gboolean gconf_writable;
+  gboolean accel_path_unlocked;
 } KeyEntry;
 
 typedef struct
 {
   KeyEntry *key_entry;
   guint n_elements;
-  gchar *user_visible_name;
+  const char *user_visible_name;
 } KeyEntryList;
 
 static KeyEntry file_entries[] =
@@ -286,7 +286,7 @@ key_from_gconf_key (const char *gconf_key)
 {
   const char *last_slash = strrchr (gconf_key, '/');
   if (last_slash)
-    return last_slash++;
+    return ++last_slash;
   return NULL;
 }
 
@@ -335,6 +335,8 @@ terminal_accels_init (void)
           gconf_client_notify (conf, key_entry->gconf_key);
 	}
     }
+
+  g_object_unref (conf);
   
   g_signal_connect (notification_group, "accel-changed",
                     G_CALLBACK (accel_changed_callback), NULL);
@@ -395,7 +397,6 @@ keys_change_notify (GConfClient *client,
   KeyEntry *key_entry;
   GdkModifierType mask;
   guint keyval;
-  gboolean gconf_writable;
 
   _terminal_debug_print (TERMINAL_DEBUG_ACCELS,
                          "key %s changed\n",
@@ -404,7 +405,7 @@ keys_change_notify (GConfClient *client,
   val = gconf_entry_get_value (entry);
 
 #ifdef GNOME_ENABLE_DEBUG
-  _TERMINAL_DEBUG_IF (TERMINAL_DEBUG_GEOMETRY)
+  _TERMINAL_DEBUG_IF (TERMINAL_DEBUG_ACCELS)
     {
       if (val == NULL)
         _terminal_debug_print (TERMINAL_DEBUG_ACCELS, " changed to be unset\n");
@@ -438,15 +439,9 @@ keys_change_notify (GConfClient *client,
   key_entry->gconf_keyval = keyval;
   key_entry->gconf_mask = mask;
 
-  gconf_writable = gconf_entry_get_is_writable (entry);
-  if (gconf_writable != key_entry->gconf_writable)
-    {
-      if (gconf_writable)
-        gtk_accel_map_unlock_path (key_entry->accel_path);
-      else
-        gtk_accel_map_lock_path (key_entry->accel_path);
-    }
-  key_entry->gconf_writable = gconf_writable;
+  /* Unlock the path, so we can change its accel */
+  if (!key_entry->accel_path_unlocked)
+    gtk_accel_map_unlock_path (key_entry->accel_path);
 
   /* sync over to GTK */
   _terminal_debug_print (TERMINAL_DEBUG_ACCELS,
@@ -460,6 +455,11 @@ keys_change_notify (GConfClient *client,
                               TRUE);
   inside_gconf_notify -= 1;
 
+  /* Lock the path if the gconf key isn't writable */
+  key_entry->accel_path_unlocked = gconf_entry_get_is_writable (entry);
+  if (!key_entry->accel_path_unlocked)
+    gtk_accel_map_lock_path (key_entry->accel_path);
+
   /* This seems necessary to update the tree model, since sometimes the
    * notification on the notification_group seems not to be emitted correctly.
    * Without this change, when trying to set an accel to e.g. Alt-T (while the main
@@ -629,8 +629,8 @@ accel_set_func (GtkTreeViewColumn *tree_column,
   else
     g_object_set (cell,
                   "visible", TRUE,
-                  "sensitive", ke->gconf_writable,
-                  "editable", ke->gconf_writable,
+                  "sensitive", ke->accel_path_unlocked,
+                  "editable", ke->accel_path_unlocked,
                   "accel-key", ke->gconf_keyval,
                   "accel-mods", ke->gconf_mask,
 		  NULL);
@@ -770,7 +770,7 @@ accel_edited_callback (GtkCellRendererAccel *cell,
                          gdk_keyval_name (keyval) ? gdk_keyval_name (keyval) : "null",
                          str);
 #ifdef GNOME_ENABLE_DEBUG
-  _TERMINAL_DEBUG_IF (TERMINAL_DEBUG_GEOMETRY)
+  _TERMINAL_DEBUG_IF (TERMINAL_DEBUG_ACCELS)
     {
       GtkAccelKey old_key;
 
@@ -938,7 +938,7 @@ terminal_edit_keys_dialog_show (GtkWindow *transient_parent)
   tree = edit_keys_store = gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER);
 
 #ifdef GNOME_ENABLE_DEBUG
-  _TERMINAL_DEBUG_IF (TERMINAL_DEBUG_GEOMETRY)
+  _TERMINAL_DEBUG_IF (TERMINAL_DEBUG_ACCELS)
     g_signal_connect (tree, "row-changed", G_CALLBACK (row_changed), NULL);
 #endif
 
