@@ -31,7 +31,9 @@ _terminal_debug_init(void)
   const GDebugKey keys[] = {
     { "accels",    TERMINAL_DEBUG_ACCELS    },
     { "encodings", TERMINAL_DEBUG_ENCODINGS },
+    { "factory",   TERMINAL_DEBUG_FACTORY   },
     { "geometry",  TERMINAL_DEBUG_GEOMETRY  },
+    { "mdi",       TERMINAL_DEBUG_MDI       },
     { "profile",   TERMINAL_DEBUG_PROFILE   }
   };
 
