@@ -56,13 +56,6 @@ typedef enum
   TERMINAL_BACKGROUND_TRANSPARENT
 } TerminalBackgroundType;
 
-typedef enum
-{
-  TERMINAL_CURSOR_BLINK_SYSTEM,
-  TERMINAL_CURSOR_BLINK_ON,
-  TERMINAL_CURSOR_BLINK_OFF
-} TerminalCursorBlinkMode;
-
 #define TERMINAL_PALETTE_SIZE 16
 
 #define TERMINAL_PALETTE_TANGO 0
@@ -80,6 +73,7 @@ typedef enum
 #define TERMINAL_PROFILE_BACKGROUND_TYPE        "background-type"
 #define TERMINAL_PROFILE_BACKSPACE_BINDING      "backspace-binding"
 #define TERMINAL_PROFILE_CURSOR_BLINK_MODE      "cursor-blink-mode"
+#define TERMINAL_PROFILE_CURSOR_SHAPE           "cursor-shape"
 #define TERMINAL_PROFILE_CUSTOM_COMMAND         "custom-command"
 #define TERMINAL_PROFILE_DEFAULT_SHOW_MENUBAR   "default-show-menubar"
 #define TERMINAL_PROFILE_DELETE_BINDING         "delete-binding"
@@ -88,7 +82,6 @@ typedef enum
 #define TERMINAL_PROFILE_FOREGROUND_COLOR       "foreground-color"
 #define TERMINAL_PROFILE_LOGIN_SHELL            "login-shell"
 #define TERMINAL_PROFILE_NAME                   "name"
-#define TERMINAL_PROFILE_NO_AA_WITHOUT_RENDER   "no-aa-without-render"
 #define TERMINAL_PROFILE_PALETTE                "palette"
 #define TERMINAL_PROFILE_SCROLL_BACKGROUND      "scroll-background"
 #define TERMINAL_PROFILE_SCROLLBACK_LINES       "scrollback-lines"
@@ -104,7 +97,7 @@ typedef enum
 #define TERMINAL_PROFILE_USE_SYSTEM_FONT        "use-system-font"
 #define TERMINAL_PROFILE_USE_THEME_COLORS       "use-theme-colors"
 #define TERMINAL_PROFILE_VISIBLE_NAME           "visible-name"
-#define TERMINAL_PROFILE_WORD_CHARS             "word-chards"
+#define TERMINAL_PROFILE_WORD_CHARS             "word-chars"
 
 /* TerminalProfile object */
 
@@ -161,7 +154,7 @@ gconstpointer     terminal_profile_get_property_boxed     (TerminalProfile *prof
 double            terminal_profile_get_property_double    (TerminalProfile *profile,
                                                            const char *prop_name);
 
-glong             terminal_profile_get_property_enum      (TerminalProfile *profile,
+int               terminal_profile_get_property_enum      (TerminalProfile *profile,
                                                            const char *prop_name);
 
 int               terminal_profile_get_property_int       (TerminalProfile *profile,
@@ -184,7 +177,7 @@ void              terminal_profile_set_palette_builtin    (TerminalProfile *prof
                                                            guint n);
 
 gboolean          terminal_profile_modify_palette_entry   (TerminalProfile *profile,
-                                                           int              i,
+                                                           guint            i,
                                                            const GdkColor  *color);
 
 G_END_DECLS
